########
AMI Kiln
########

**This is an ongoing Python port of the proof of concept library: `kiln-php https://github.com/samkeen/kiln-php`**

*******
Summary
*******

This is a Packer based AMI building system. Its goal is to simplify and help organize the creation of AMIs.

